@@ -21,8 +21,8 @@ class nectar(ExtracteurDeJus):
 
     def success(self):
         p = Path(random.choice(self.success_files), encoding=None)
-        play_file(Path(str(PurePosixPath(p))))
+        play_file(p)
 
     def failure(self):
         p = Path(random.choice(self.failure_files), encoding=None)
-        play_file(Path(str(PurePosixPath(p))))
+        play_file(p)
